@@ -1,3 +1,4 @@
+# coding: utf-8
 import urllib
 from tornado import gen
 from tornado.httpclient import HTTPRequest, AsyncHTTPClient
@@ -31,6 +32,9 @@ class Venues(object):
 
     @gen.engine
     def search(self, callback, **kw):
+        if 'query' in kw:
+            kw['query'] = kw['query'].encode('utf-8')
+
         response = yield gen.Task(self.foursquare._make_request, path='/venues/search', query=kw)
         callback(response.get('response').get('venues'))
 
